# -*- coding: utf-8 -*-

"""
lassie.helpers
~~~~~~~~~~~~~~

This module contains the set of helper functions executed by Lassie methods.

"""

from .compat import str

import locale
import re

CLEANER = re.compile(r'[\r\n\t]')
RE_INT = re.compile(r'\d+')

def clean_text(value):
    """Removes all line breaks, new lines and tabs from the specified content

    :param value: Content to be cleansed
    :type value: string

    """
    return CLEANER.sub('', value)

def convert_to_int(value):
    """Attempts to convert a specified value to an integer

    :param value: Content to be converted into an integer
    :type value: string or int

    """
    if not value:
        return None

    # Apart from numbers also accept values that end with px
    value = value.strip(' px')
    try:
        return int(value)
    except (TypeError, ValueError):
        return None

def normalize_locale(value):
    value = value.replace('-', '_')
    the_locale = locale.normalize(value)

    if the_locale != value:
        # Should we return the actual locale, returned from the locale lib instead of splitting?
        try:
            return str(the_locale.split('.')[0])
        except IndexError:  # pragma: no cover
            pass
    return None




# -*- coding: utf-8 -*-

"""
lassie.compat
~~~~~~~~~~~~~

This module contains imports and declarations for seamless Python 2 and
Python 3 compatibility.
"""

import sys

_ver = sys.version_info

#: Python 2.x?
is_py2 = (_ver[0] == 2)

#: Python 3.x?
is_py3 = (_ver[0] == 3)

if is_py2:
    from urlparse import urljoin, urlparse

    str = unicode

elif is_py3:
    from urllib.parse import urljoin, urlparse

    str = str



# -*- coding: utf-8 -*-

"""
lassie.exceptions
~~~~~~~~~~~~~~~~~

This module contains the set of Lassie exceptions.

"""

class LassieError(Exception):
    """Generic catch-all Exceptions"""
    pass
